@@ -58,11 +58,6 @@ void GlobalBookmarkManager::saveAs(const QString &fileName)
     mgr()->saveAs(fileName);
 }
 
-void GlobalBookmarkManager::setUpdate(bool update)
-{
-    mgr()->setUpdate(update);
-}
-
 QString GlobalBookmarkManager::path() const
 {
     return mgr()->path();
@@ -95,11 +90,6 @@ void GlobalBookmarkManager::notifyManagers()
     notifyManagers(root());
 }
 
-void GlobalBookmarkManager::reloadConfig()
-{
-    mgr()->emitConfigChanged();
-}
-
 QString GlobalBookmarkManager::makeTimeStr(const QString &in)
 {
     int secs;
